==> phpsysinfo_2.5.1.orig.tar.gz: phpsysinfo/includes/lang/ro.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: ro.php,v 1.0 6/9/01 12:41PM 
// Translated by Silviu Simen - ssimen@sympatico.ca

$text['title']          = 'Informatii despre sistem';

$text['vitals']         = 'Informatii vitale';
$text['hostname']       = 'Numele canonic';
$text['ip']             = 'Adresa IP';
$text['kversion']       = 'Versiune nucleu';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Timp de viata';
$text['users']          = 'Utilizatori curenti';
$text['loadavg']        = 'Incarcarea sistemului';

$text['hardware']       = 'Informatii hardware';
$text['numcpu']         = 'Procesoare';
$text['cpumodel']       = 'Model';
$text['cpuspeed']       = 'CPU Speed';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = 'Marime Cache';
$text['bogomips']       = 'Bogomips';

$text['pci']            = 'Dispozitive PCI';
$text['ide']            = 'Dispozitive IDE';
$text['scsi']           = 'Dispozitive SCSI';
$text['usb']            = 'Dispozitive USB';

$text['netusage']       = 'Utilizarea retelei';
$text['device']         = 'Dispozitiv';
$text['received']       = 'Primit';
$text['sent']           = 'Trimis';
$text['errors']         = 'Erori';

$text['memusage']       = 'Utilizarea memoriei';
$text['phymem']         = 'Memorie fizica';
$text['swap']           = 'Disk Swap';

$text['fs']             = 'Sisteme de fisiere montate';
$text['mount']          = 'Punct montare';
$text['partition']      = 'Partitie';

$text['percent']        = 'Procent capacitate';
$text['type']           = 'Tip';
$text['free']           = 'Liber';
$text['used']           = 'Utilizat';
$text['size']           = 'Marime';
$text['totals']         = 'Total';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'nici unul';

$text['capacity']       = 'Capacitate';

$text['template']       = 'Model';
$text['language']       = 'Limba';
$text['submit']         = 'Actualizeaza';
$text['created']        = 'Creat de';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %I:%M %p';

$text['days']           = 'zile';
$text['hours']          = 'ore';
$text['minutes']        = 'minute';
  
$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degree_mark']    = '&ordm;C';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= '- Kernel + applications';
$text['buffers']	= '- Buffers';
$text['cached']		= '- Cached';

?>

==> phpsysinfo_2.5.2.orig.tar.gz: phpsysinfo/includes/lang/ro.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: ro.php,v 1.0 6/9/01 12:41PM 
// Translated by Silviu Simen - ssimen@sympatico.ca

$text['title']          = 'Informatii despre sistem';

$text['vitals']         = 'Informatii vitale';
$text['hostname']       = 'Numele canonic';
$text['ip']             = 'Adresa IP';
$text['kversion']       = 'Versiune nucleu';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Timp de viata';
$text['users']          = 'Utilizatori curenti';
$text['loadavg']        = 'Incarcarea sistemului';

$text['hardware']       = 'Informatii hardware';
$text['numcpu']         = 'Procesoare';
$text['cpumodel']       = 'Model';
$text['cpuspeed']       = 'CPU Speed';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = 'Marime Cache';
$text['bogomips']       = 'Bogomips';

$text['pci']            = 'Dispozitive PCI';
$text['ide']            = 'Dispozitive IDE';
$text['scsi']           = 'Dispozitive SCSI';
$text['usb']            = 'Dispozitive USB';

$text['netusage']       = 'Utilizarea retelei';
$text['device']         = 'Dispozitiv';
$text['received']       = 'Primit';
$text['sent']           = 'Trimis';
$text['errors']         = 'Erori';

$text['memusage']       = 'Utilizarea memoriei';
$text['phymem']         = 'Memorie fizica';
$text['swap']           = 'Disk Swap';

$text['fs']             = 'Sisteme de fisiere montate';
$text['mount']          = 'Punct montare';
$text['partition']      = 'Partitie';

$text['percent']        = 'Procent capacitate';
$text['type']           = 'Tip';
$text['free']           = 'Liber';
$text['used']           = 'Utilizat';
$text['size']           = 'Marime';
$text['totals']         = 'Total';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'nici unul';

$text['capacity']       = 'Capacitate';

$text['template']       = 'Model';
$text['language']       = 'Limba';
$text['submit']         = 'Actualizeaza';
$text['created']        = 'Creat de';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %I:%M %p';

$text['days']           = 'zile';
$text['hours']          = 'ore';
$text['minutes']        = 'minute';
  
$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degreeC']        = '&ordm;C';
$text['degreeF']        = '&ordm;F';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= 'Kernel + applications';
$text['buffers']	= 'Buffers';
$text['cached']		= 'Cached';

$text['connections']    = 'Established Network Connections';
?>
